==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualRouterSpecListenerPortMappingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualRouterSpecListenerPortMappingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property port Port used for the port mapping.
 * @property protocol Protocol used for the port mapping. Valid values are `http`,`http2`, `tcp` and `grpc`.
 */
public data class VirtualRouterSpecListenerPortMappingArgs(
    public val port: Output<Int>,
    public val protocol: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualRouterSpecListenerPortMappingArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualRouterSpecListenerPortMappingArgs =
        com.pulumi.aws.appmesh.inputs.VirtualRouterSpecListenerPortMappingArgs.builder()
            .port(port.applyValue({ args0 -> args0 }))
            .protocol(protocol.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualRouterSpecListenerPortMappingArgs].
 */
@PulumiTagMarker
public class VirtualRouterSpecListenerPortMappingArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var protocol: Output<String>? = null

    /**
     * @param value Port used for the port mapping.
     */
    @JvmName("oacxyqeppuvmatnv")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Protocol used for the port mapping. Valid values are `http`,`http2`, `tcp` and `grpc`.
     */
    @JvmName("qewditxlwhtogkqj")
    public suspend fun protocol(`value`: Output<String>) {
        this.protocol = value
    }

    /**
     * @param value Port used for the port mapping.
     */
    @JvmName("lwlkibhaggbfvvno")
    public suspend fun port(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Protocol used for the port mapping. Valid values are `http`,`http2`, `tcp` and `grpc`.
     */
    @JvmName("xdbixgotmqsuexkn")
    public suspend fun protocol(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    internal fun build(): VirtualRouterSpecListenerPortMappingArgs =
        VirtualRouterSpecListenerPortMappingArgs(
            port = port ?: throw PulumiNullFieldException("port"),
            protocol = protocol ?: throw PulumiNullFieldException("protocol"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualRouterSpecListenerPortMappingArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualRouterSpecListenerPortMappingArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property port Port used for the port mapping.
 * @property protocol Protocol used for the port mapping. Valid values are `http`,`http2`, `tcp` and `grpc`.
 */
public data class VirtualRouterSpecListenerPortMappingArgs(
    public val port: Output<Int>,
    public val protocol: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualRouterSpecListenerPortMappingArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualRouterSpecListenerPortMappingArgs =
        com.pulumi.aws.appmesh.inputs.VirtualRouterSpecListenerPortMappingArgs.builder()
            .port(port.applyValue({ args0 -> args0 }))
            .protocol(protocol.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualRouterSpecListenerPortMappingArgs].
 */
@PulumiTagMarker
public class VirtualRouterSpecListenerPortMappingArgsBuilder internal constructor() {
    private var port: Output<Int>? = null

    private var protocol: Output<String>? = null

    /**
     * @param value Port used for the port mapping.
     */
    @JvmName("aailtgvcwptwthfg")
    public suspend fun port(`value`: Output<Int>) {
        this.port = value
    }

    /**
     * @param value Protocol used for the port mapping. Valid values are `http`,`http2`, `tcp` and `grpc`.
     */
    @JvmName("lpmkxkktixbnsvpc")
    public suspend fun protocol(`value`: Output<String>) {
        this.protocol = value
    }

    /**
     * @param value Port used for the port mapping.
     */
    @JvmName("xnipjmqemudldirm")
    public suspend fun port(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.port = mapped
    }

    /**
     * @param value Protocol used for the port mapping. Valid values are `http`,`http2`, `tcp` and `grpc`.
     */
    @JvmName("foymtyqtcvlqedws")
    public suspend fun protocol(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.protocol = mapped
    }

    internal fun build(): VirtualRouterSpecListenerPortMappingArgs =
        VirtualRouterSpecListenerPortMappingArgs(
            port = port ?: throw PulumiNullFieldException("port"),
            protocol = protocol ?: throw PulumiNullFieldException("protocol"),
        )
}
